package Gtk2::ImageView;
use Gtk2;
require DynaLoader;
our @ISA = qw(DynaLoader);
our $VERSION = '0.01';
sub dl_load_flags {0x01};
bootstrap Gtk2::ImageView $VERSION;
1;
__END__

This is not the POD you're looking for.

The documentation for this module is generated from the XS source, and is stored in separate .pod files.

=cut
